==> financial-settlement-metadata-0.1.54-sources.jar: com/xforceplus/ultraman/app/financialsettlement/metadata/meta/FormMeta.java <==
package com.xforceplus.ultraman.app.financialsettlement.metadata.meta;

/**
 * 表单元数据
 *
 * @author ultraman
 * @since 2022-06-30
 */

public class FormMeta {
    public interface CapitalFlowNoClaim {
        static String code() {
            return "capitalFlowNoClaim";
        }
        static String name() {
            return "回款-未认领";
        }
    }
    public interface FinancialTravelApplyBill {
        static String code() {
            return "financialTravelApplyBill";
        }
        static String name() {
            return "差旅申请单表单";
        }
    }
    public interface FinancialCityReimbursementBill {
        static String code() {
            return "financialCityReimbursementBill";
        }
        static String name() {
            return "市内交通报销单表单";
        }
    }
    public interface FinancialBusinessServeReimbursementBill {
        static String code() {
            return "financialBusinessServeReimbursementBill";
        }
        static String name() {
            return "业务招待报销单表单";
        }
    }
    public interface FinancialHesWriteoffBill {
        static String code() {
            return "financialHesWriteoffBill";
        }
        static String name() {
            return "合思订单核销单表单";
        }
    }
    public interface FinancialTravelReimbursementBill {
        static String code() {
            return "financialTravelReimbursementBill";
        }
        static String name() {
            return "差旅报销单表单";
        }
    }
    public interface FinancialTeamBuildingBill {
        static String code() {
            return "financialTeamBuildingBill";
        }
        static String name() {
            return "团建费报销单";
        }
    }
    public interface FinancialPurchaseBill {
        static String code() {
            return "financialPurchaseBill";
        }
        static String name() {
            return "采购申请单";
        }
    }
    public interface FinancialDailyBill {
        static String code() {
            return "financialDailyBill";
        }
        static String name() {
            return "日常报销单";
        }
    }
    public interface FinancialPurchaseContractBill {
        static String code() {
            return "financialPurchaseContractBill";
        }
        static String name() {
            return "采购合同申请单";
        }
    }
    public interface FinancialPurchaseCheckBill {
        static String code() {
            return "financialPurchaseCheckBill";
        }
        static String name() {
            return " 采购验收单";
        }
    }
    public interface FinancialPersonLoanBill {
        static String code() {
            return "financialPersonLoanBill";
        }
        static String name() {
            return "个人借款申请单";
        }
    }
    public interface FinancialPersonLoanBackBill {
        static String code() {
            return "financialPersonLoanBackBill";
        }
        static String name() {
            return "个人借款归还单";
        }
    }
    public interface FinancialPurchasePaymentBill {
        static String code() {
            return "financialPurchasePaymentBill";
        }
        static String name() {
            return "采购付款申请单";
        }
    }
    public interface FinancialRefundBill {
        static String code() {
            return "financialRefundBill";
        }
        static String name() {
            return "退款申请单";
        }
    }
    public interface FinancialAssetsBill {
        static String code() {
            return "financialAssetsBill";
        }
        static String name() {
            return "资产的领用及更换申请单";
        }
    }
    public interface FinancialAssetsBackBill {
        static String code() {
            return "financialAssetsBackBill";
        }
        static String name() {
            return "资产的归还申请单";
        }
    }
    public interface FinancialInvoicePledgeBill {
        static String code() {
            return "financialInvoicePledgeBill";
        }
        static String name() {
            return "发票押金核销单";
        }
    }
    public interface FinancialAssetsTransferBill {
        static String code() {
            return "financialAssetsTransferBill";
        }
        static String name() {
            return "资产调拨转移申请单";
        }
    }
    public interface FinancialPurchaseAfterSaleBill {
        static String code() {
            return "financialPurchaseAfterSaleBill";
        }
        static String name() {
            return "采购售后申请单";
        }
    }
    public interface FinancialKeeperChangeBill {
        static String code() {
            return "financialKeeperChangeBill";
        }
        static String name() {
            return "保管人变更申请单";
        }
    }
    public interface FinancialResponsibleChangeBill {
        static String code() {
            return "financialResponsibleChangeBill";
        }
        static String name() {
            return "责任人变更";
        }
    }
    public interface FinancialInventorySaleDeliveryBill {
        static String code() {
            return "financialInventorySaleDeliveryBill";
        }
        static String name() {
            return "存货销售出库申请单";
        }
    }
    public interface FinancialSaleReturnBill {
        static String code() {
            return "financialSaleReturnBill";
        }
        static String name() {
            return "销售退回退库申请单";
        }
    }
    public interface FinancialPurchAsassetBorrowBill {
        static String code() {
            return "financialPurchAsassetBorrowBill";
        }
        static String name() {
            return "生产性资产借用申请单";
        }
    }
    public interface FinancialAssembleBill {
        static String code() {
            return "financialAssembleBill";
        }
        static String name() {
            return "装配申请单";
        }
    }
    public interface FinancialDisassemblyBill {
        static String code() {
            return "financialDisassemblyBill";
        }
        static String name() {
            return "拆卸申请单";
        }
    }
    public interface FinancialTransferBill {
        static String code() {
            return "financialTransferBill";
        }
        static String name() {
            return "转库申请单";
        }
    }
    public interface FinancialAccessoriesrReplaceBill {
        static String code() {
            return "financialAccessoriesrReplaceBill";
        }
        static String name() {
            return "配件补领或替换申请单";
        }
    }
    public interface FinancialAssetCheckBill {
        static String code() {
            return "financialAssetCheckBill";
        }
        static String name() {
            return "资产盘点申请单";
        }
    }
    public interface FinancialAssetScrapBill {
        static String code() {
            return "financialAssetScrapBill";
        }
        static String name() {
            return "资产报废及处理申请单";
        }
    }
    public interface FinancialSalaryBill {
        static String code() {
            return "financialSalaryBill";
        }
        static String name() {
            return "薪资申请单";
        }
    }
    public interface FinancialInvoiceCheckBill {
        static String code() {
            return "financialInvoiceCheckBill";
        }
        static String name() {
            return "发票核销单";
        }
    }
    public interface FinancialLaborUnionBill {
        static String code() {
            return "financialLaborUnionBill";
        }
        static String name() {
            return "工会申请单";
        }
    }
    public interface FinancialPurchaseRedAdjustBill {
        static String code() {
            return "financialPurchaseRedAdjustBill";
        }
        static String name() {
            return "采购红冲调整单";
        }
    }
    public interface FinancialProjectShareAdjustBill {
        static String code() {
            return "financialProjectShareAdjustBill";
        }
        static String name() {
            return "项目分摊调整单";
        }
    }
    public interface FinancialCostTypeAdjustBill {
        static String code() {
            return "financialCostTypeAdjustBill";
        }
        static String name() {
            return "费用类型调整单";
        }
    }
    public interface PreComputeTaxNoInfo {
        static String code() {
            return "preComputeTaxNoInfo";
        }
        static String name() {
            return "税号台账";
        }
    }
}

==> financial-settlement-metadata-0.1.268-sources.jar: com/xforceplus/ultraman/app/financialsettlement/metadata/meta/FormMeta.java <==
package com.xforceplus.ultraman.app.financialsettlement.metadata.meta;

/**
 * 表单元数据
 *
 * @author ultraman
 * @since 2022-09-23
 */

public class FormMeta {
    public interface CapitalFlowNoClaim {
        static String code() {
            return "capitalFlowNoClaim";
        }
        static String name() {
            return "回款-未认领";
        }
    }
    public interface FinancialTravelApplyBill {
        static String code() {
            return "financialTravelApplyBill";
        }
        static String name() {
            return "差旅申请单表单";
        }
    }
    public interface FinancialCityReimbursementBill {
        static String code() {
            return "financialCityReimbursementBill";
        }
        static String name() {
            return "市内交通费报销单表单";
        }
    }
    public interface FinancialBusinessServeReimbursementBill {
        static String code() {
            return "financialBusinessServeReimbursementBill";
        }
        static String name() {
            return "业务招待报销单表单";
        }
    }
    public interface FinancialHesWriteoffBill {
        static String code() {
            return "financialHesWriteoffBill";
        }
        static String name() {
            return "合思订单核销单表单";
        }
    }
    public interface FinancialTravelReimbursementBill {
        static String code() {
            return "financialTravelReimbursementBill";
        }
        static String name() {
            return "差旅报销单表单";
        }
    }
    public interface FinancialTeamBuildingBill {
        static String code() {
            return "financialTeamBuildingBill";
        }
        static String name() {
            return "团建费报销单";
        }
    }
    public interface FinancialPurchaseBill {
        static String code() {
            return "financialPurchaseBill";
        }
        static String name() {
            return "采购申请单";
        }
    }
    public interface FinancialDailyBill {
        static String code() {
            return "financialDailyBill";
        }
        static String name() {
            return "日常报销单";
        }
    }
    public interface FinancialPurchaseContractBill {
        static String code() {
            return "financialPurchaseContractBill";
        }
        static String name() {
            return "采购合同申请单";
        }
    }
    public interface FinancialPurchaseCheckBill {
        static String code() {
            return "financialPurchaseCheckBill";
        }
        static String name() {
            return " 采购验收单";
        }
    }
    public interface FinancialPersonLoanBill {
        static String code() {
            return "financialPersonLoanBill";
        }
        static String name() {
            return "个人借款申请单";
        }
    }
    public interface FinancialPersonLoanBackBill {
        static String code() {
            return "financialPersonLoanBackBill";
        }
        static String name() {
            return "个人借款归还单";
        }
    }
    public interface FinancialPurchasePaymentBill {
        static String code() {
            return "financialPurchasePaymentBill";
        }
        static String name() {
            return "采购付款申请单";
        }
    }
    public interface FinancialRefundBill {
        static String code() {
            return "financialRefundBill";
        }
        static String name() {
            return "退款申请单";
        }
    }
    public interface FinancialAssetsBill {
        static String code() {
            return "financialAssetsBill";
        }
        static String name() {
            return "资产的领用及更换申请单";
        }
    }
    public interface FinancialAssetsBackBill {
        static String code() {
            return "financialAssetsBackBill";
        }
        static String name() {
            return "资产的归还申请单";
        }
    }
    public interface FinancialInvoicePledgeBill {
        static String code() {
            return "financialInvoicePledgeBill";
        }
        static String name() {
            return "发票押金核销单";
        }
    }
    public interface FinancialAssetsTransferBill {
        static String code() {
            return "financialAssetsTransferBill";
        }
        static String name() {
            return "资产调拨转移申请单";
        }
    }
    public interface FinancialPurchaseAfterSaleBill {
        static String code() {
            return "financialPurchaseAfterSaleBill";
        }
        static String name() {
            return "采购售后申请单";
        }
    }
    public interface FinancialKeeperChangeBill {
        static String code() {
            return "financialKeeperChangeBill";
        }
        static String name() {
            return "保管人变更申请单";
        }
    }
    public interface FinancialResponsibleChangeBill {
        static String code() {
            return "financialResponsibleChangeBill";
        }
        static String name() {
            return "责任人变更";
        }
    }
    public interface FinancialInventorySaleDeliveryBill {
        static String code() {
            return "financialInventorySaleDeliveryBill";
        }
        static String name() {
            return "存货销售出库申请单";
        }
    }
    public interface FinancialSaleReturnBill {
        static String code() {
            return "financialSaleReturnBill";
        }
        static String name() {
            return "销售退回退库申请单";
        }
    }
    public interface FinancialPurchAsassetBorrowBill {
        static String code() {
            return "financialPurchAsassetBorrowBill";
        }
        static String name() {
            return "生产性资产借用申请单";
        }
    }
    public interface FinancialAssembleBill {
        static String code() {
            return "financialAssembleBill";
        }
        static String name() {
            return "装配申请单";
        }
    }
    public interface FinancialDisassemblyBill {
        static String code() {
            return "financialDisassemblyBill";
        }
        static String name() {
            return "拆卸申请单";
        }
    }
    public interface FinancialTransferBill {
        static String code() {
            return "financialTransferBill";
        }
        static String name() {
            return "转库申请单";
        }
    }
    public interface FinancialAccessoriesrReplaceBill {
        static String code() {
            return "financialAccessoriesrReplaceBill";
        }
        static String name() {
            return "配件补领或替换申请单";
        }
    }
    public interface FinancialAssetCheckBill {
        static String code() {
            return "financialAssetCheckBill";
        }
        static String name() {
            return "资产盘点申请单";
        }
    }
    public interface FinancialAssetScrapBill {
        static String code() {
            return "financialAssetScrapBill";
        }
        static String name() {
            return "资产报废及处理申请单";
        }
    }
    public interface FinancialSalaryBill {
        static String code() {
            return "financialSalaryBill";
        }
        static String name() {
            return "薪资申请单";
        }
    }
    public interface FinancialInvoiceCheckBill {
        static String code() {
            return "financialInvoiceCheckBill";
        }
        static String name() {
            return "发票核销单";
        }
    }
    public interface FinancialLaborUnionBill {
        static String code() {
            return "financialLaborUnionBill";
        }
        static String name() {
            return "工会申请单";
        }
    }
    public interface FinancialPurchaseRedAdjustBill {
        static String code() {
            return "financialPurchaseRedAdjustBill";
        }
        static String name() {
            return "采购红冲调整单";
        }
    }
    public interface FinancialProjectShareAdjustBill {
        static String code() {
            return "financialProjectShareAdjustBill";
        }
        static String name() {
            return "项目分摊调整单";
        }
    }
    public interface FinancialCostTypeAdjustBill {
        static String code() {
            return "financialCostTypeAdjustBill";
        }
        static String name() {
            return "费用类型调整单";
        }
    }
    public interface PreComputeTaxNoInfo {
        static String code() {
            return "preComputeTaxNoInfo";
        }
        static String name() {
            return "税号台账";
        }
    }
    public interface FinancialBusinessServeApplyBill {
        static String code() {
            return "financialBusinessServeApplyBill";
        }
        static String name() {
            return "业务招待申请单";
        }
    }
}
